@@ -31,17 +31,16 @@
 #define _GNUstep_H_NSCell
 #import <GNUstepBase/GSVersionMacros.h>
 
-#include <Foundation/NSCoder.h>
-#include <Foundation/NSGeometry.h>
+#import <Foundation/NSGeometry.h>
 
 // For tint
-#include <AppKit/NSColor.h>
+#import <AppKit/NSColor.h>
 // for NSWritingDirection
-#include <AppKit/NSParagraphStyle.h>
+#import <AppKit/NSParagraphStyle.h>
 // For text alignment
-#include <AppKit/NSText.h>
+#import <AppKit/NSText.h>
 // for NSFocusRingType
-#include <AppKit/NSView.h>
+#import <AppKit/NSView.h>
 
 @class NSString;
 @class NSMutableDictionary;
@@ -140,7 +139,7 @@ enum {
     unsigned is_bordered: 1;   
     unsigned is_bezeled: 1;   
     unsigned is_scrollable: 1;
-    unsigned wraps: 1;
+    unsigned reserved: 1;
     unsigned text_align: 3; // 5 values
     unsigned is_selectable: 1;
     unsigned allows_mixed_state: 1;
@@ -205,7 +204,11 @@ enum {
 - (void)setFloatValue:(float)aFloat;
 - (void)setIntValue:(int)anInt;
 - (void)setStringValue:(NSString *)aString;
-
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_5, GS_API_LATEST)
+- (NSInteger) integerValue;
+- (void) setIntegerValue: (NSInteger)anInt;
+- (void) takeIntegerValueFrom: (id)sender;
+#endif
 //
 // Setting Parameters 
 //
@@ -301,8 +304,8 @@ enum {
 //
 // Assigning a Tag 
 //
-- (void)setTag:(int)anInt;
-- (int)tag;
+- (void)setTag:(NSInteger)anInt;
+- (NSInteger)tag;
 
 //
 // Formatting Data and Validating Input 
@@ -491,6 +494,10 @@ enum {
                                     inView: (NSView*)controlView;
 - (void) _drawFocusRingWithFrame: (NSRect)cellFrame 
                           inView: (NSView*)controlView;
+- (void) _drawEditorWithFrame: (NSRect)cellFrame
+		       inView: (NSView*)controlView;
+- (void) _setInEditing: (BOOL)flag;
+- (void) _updateFieldEditor: (NSText*)textObject;
 @end
 
 #endif // _GNUstep_H_NSCell
