@@ -30,11 +30,11 @@
 #define _GNUstep_H_NSMenu
 #import <GNUstepBase/GSVersionMacros.h>
 
-#include <Foundation/NSObject.h>
-#include <Foundation/NSGeometry.h>
+#import <Foundation/NSObject.h>
+#import <Foundation/NSGeometry.h>
 
-#include <AppKit/NSMenuItem.h>
-#include <AppKit/AppKitDefines.h>
+#import <AppKit/NSMenuItem.h>
+#import <AppKit/AppKitDefines.h>
 
 @class NSString;
 @class NSEvent;
@@ -347,7 +347,8 @@
     unsigned int is_tornoff: 1;
     unsigned int transient: 1;
     unsigned int horizontal: 1;
-		unsigned int unused: 26;
+	unsigned int mainMenuChanged: 1;
+		unsigned int unused: 25;
   } _menu;
 
 @private
