@@ -32,9 +32,10 @@
 
 #ifndef _GNUstep_H_NSView
 #define _GNUstep_H_NSView
+#import <GNUstepBase/GSVersionMacros.h>
 
-#include <AppKit/NSGraphicsContext.h>
-#include <AppKit/NSResponder.h>
+#import <AppKit/NSGraphicsContext.h>
+#import <AppKit/NSResponder.h>
 
 @class NSArray;
 @class NSAttributedString;
@@ -104,10 +105,14 @@ typedef enum _NSFocusRingType {
   id _matrixFromWindow;
 
   NSView* _super_view;
+PACKAGE_SCOPE
   NSMutableArray *_sub_views;
+@protected
   NSWindow *_window;
+PACKAGE_SCOPE
   NSMutableArray *_tracking_rects;
   NSMutableArray *_cursor_rects;
+@protected
   NSRect _invalidRect;
   NSRect _visibleRect;
   int _gstate;
@@ -136,6 +141,8 @@ typedef enum _NSFocusRingType {
     unsigned	valid_rects:1;		/* Some cursor rects may be ok.	*/
     unsigned	needs_display:1;	/* view needs display.   	*/
     unsigned	has_tooltips:1;		/* The view has tooltips set.	*/
+    unsigned	ignores_backing:1;      /* The view does not trigger    */
+                                        /* backing flush when drawn     */
   } _rFlags;
 
   BOOL _is_rotated_from_base;
@@ -192,8 +199,8 @@ typedef enum _NSFocusRingType {
 /*
  * Assigning a Tag
  */
-- (int) tag;
-- (id) viewWithTag: (int)aTag;
+- (NSInteger) tag;
+- (id) viewWithTag: (NSInteger)aTag;
 
 /*
  * Modifying the Frame Rectangle
@@ -588,6 +595,10 @@ typedef enum _NSFocusRingType {
 
 - (NSAffineTransform*) _matrixToWindow;
 - (NSAffineTransform*) _matrixFromWindow;
+
+- (void) _setIgnoresBacking: (BOOL) flag;
+- (BOOL) _ignoresBacking;
+
 @end
 #endif
 
@@ -600,5 +611,6 @@ APPKIT_EXPORT NSArray *GSGetDragTypes(NSView* aView);
 APPKIT_EXPORT NSString *NSViewFrameDidChangeNotification;
 APPKIT_EXPORT NSString *NSViewBoundsDidChangeNotification;
 APPKIT_EXPORT NSString *NSViewFocusDidChangeNotification;
+APPKIT_EXPORT NSString *NSViewGlobalFrameDidChangeNotification;
 
 #endif // _GNUstep_H_NSView
